@@ -23,6 +23,7 @@ from sagemaker import image_uris
 from sagemaker.amazon import validation
 from sagemaker.amazon.hyperparameter import Hyperparameter as hp  # noqa
 from sagemaker.amazon.common import write_numpy_to_dense_tensor
+from sagemaker.deprecations import renamed_warning
 from sagemaker.estimator import EstimatorBase, _TrainingJob
 from sagemaker.inputs import FileSystemInput, TrainingInput
 from sagemaker.utils import sagemaker_timestamp
@@ -43,8 +44,8 @@ class AmazonAlgorithmEstimatorBase(EstimatorBase):
     def __init__(
         self,
         role,
-        instance_count,
-        instance_type,
+        instance_count=None,
+        instance_type=None,
         data_location=None,
         enable_network_isolation=False,
         **kwargs
@@ -58,9 +59,9 @@ class AmazonAlgorithmEstimatorBase(EstimatorBase):
                 artifacts. After the endpoint is created, the inference code
                 might use the IAM role, if it needs to access an AWS resource.
             instance_count (int): Number of Amazon EC2 instances to use
-                for training.
+                for training. Required.
             instance_type (str): Type of EC2 instance to use for training,
-                for example, 'ml.c4.xlarge'.
+                for example, 'ml.c4.xlarge'. Required.
             data_location (str or None): The s3 prefix to upload RecordSet
                 objects to, expressed as an S3 url. For example
                 "s3://example-bucket/some-key-prefix/". Objects will be saved in
@@ -85,7 +86,6 @@ class AmazonAlgorithmEstimatorBase(EstimatorBase):
             enable_network_isolation=enable_network_isolation,
             **kwargs
         )
-
         data_location = data_location or "s3://{}/sagemaker-record-sets/".format(
             self.sagemaker_session.default_bucket()
         )
@@ -454,3 +454,22 @@ def upload_numpy_to_s3_shards(
                 s3.Object(bucket, key_prefix + file).delete()
         finally:
             raise ex
+
+
+def get_image_uri(region_name, repo_name, repo_version=1):
+    """Deprecated method. Please use sagemaker.image_uris.retrieve().
+
+    Args:
+        region_name: name of the region
+        repo_name: name of the repo (e.g. xgboost)
+        repo_version: version of the repo
+
+    Returns:
+        the image uri
+    """
+    renamed_warning("The method get_image_uri")
+    return image_uris.retrieve(
+        framework=repo_name,
+        region=region_name,
+        version=repo_version,
+    )
