@@ -29,7 +29,8 @@ class IPInsights(AmazonAlgorithmEstimatorBase):
     """An unsupervised learning algorithm that learns the usage patterns for IPv4 addresses.
 
     It is designed to capture associations between IPv4 addresses and various entities, such
-    as user IDs or account numbers."""
+    as user IDs or account numbers.
+    """
 
     repo_name = "ipinsights"
     repo_version = 1
@@ -59,10 +60,10 @@ class IPInsights(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        instance_count,
-        instance_type,
-        num_entity_vectors,
-        vector_dim,
+        instance_count=None,
+        instance_type=None,
+        num_entity_vectors=None,
+        vector_dim=None,
         batch_metrics_publish_interval=None,
         epochs=None,
         learning_rate=None,
