@@ -30,7 +30,8 @@ class LDA(AmazonAlgorithmEstimatorBase):
     LDA is most commonly used to discover a
     user-specified number of topics shared by documents within a text corpus. Here each
     observation is a document, the features are the presence (or occurrence count) of each
-    word, and the categories are the topics."""
+    word, and the categories are the topics.
+    """
 
     repo_name = "lda"
     repo_version = 1
@@ -44,8 +45,8 @@ class LDA(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        instance_type,
-        num_topics,
+        instance_type=None,
+        num_topics=None,
         alpha0=None,
         max_restarts=None,
         max_iterations=None,
