@@ -32,7 +32,8 @@ class LinearLearner(AmazonAlgorithmEstimatorBase):
     For multiclass classification problems, the labels must be from 0 to num_classes - 1. For
     regression problems, y is a real number. The algorithm learns a linear function, or, for
     classification problems, a linear threshold function, and maps a vector x to an approximation
-    of the label y."""
+    of the label y.
+    """
 
     repo_name = "linear-learner"
     repo_version = 1
@@ -128,9 +129,9 @@ class LinearLearner(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        instance_count,
-        instance_type,
-        predictor_type,
+        instance_count=None,
+        instance_type=None,
+        predictor_type=None,
         binary_classifier_model_selection_criteria=None,
         target_recall=None,
         target_precision=None,
