@@ -24,7 +24,8 @@ from sagemaker.vpc_utils import VPC_CONFIG_DEFAULT
 
 
 def _list_check_subset(valid_super_list):
-    """
+    """Provides a function to check validity of list subset.
+
     Args:
         valid_super_list:
     """
@@ -45,7 +46,8 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
 
     It can learn low-dimensional dense embeddings of high-dimensional objects. The embeddings
     are learned in a way that preserves the semantics of the relationship between pairs of
-    objects in the original space in the embedding space."""
+    objects in the original space in the embedding space.
+    """
 
     repo_name = "object2vec"
     repo_version = 1
@@ -138,11 +140,11 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        instance_count,
-        instance_type,
-        epochs,
-        enc0_max_seq_len,
-        enc0_vocab_size,
+        instance_count=None,
+        instance_type=None,
+        epochs=None,
+        enc0_max_seq_len=None,
+        enc0_vocab_size=None,
         enc_dim=None,
         mini_batch_size=None,
         early_stopping_patience=None,
@@ -269,7 +271,6 @@ class Object2Vec(AmazonAlgorithmEstimatorBase):
         """
 
         super(Object2Vec, self).__init__(role, instance_count, instance_type, **kwargs)
-
         self.enc_dim = enc_dim
         self.mini_batch_size = mini_batch_size
         self.epochs = epochs
