@@ -28,7 +28,8 @@ class PCA(AmazonAlgorithmEstimatorBase):
     """An unsupervised machine learning algorithm to reduce feature dimensionality.
 
     As a result, number of features within a dataset is reduced but the dataset still
-    retain as much information as possible."""
+    retain as much information as possible.
+    """
 
     repo_name = "pca"
     repo_version = 1
@@ -54,9 +55,9 @@ class PCA(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        instance_count,
-        instance_type,
-        num_components,
+        instance_count=None,
+        instance_type=None,
+        num_components=None,
         algorithm_mode=None,
         subtract_mean=None,
         extra_components=None,
