@@ -29,7 +29,8 @@ class RandomCutForest(AmazonAlgorithmEstimatorBase):
 
     These are observations which diverge from otherwise well-structured or patterned data.
     Anomalies can manifest as unexpected spikes in time series data, breaks in periodicity,
-    or unclassifiable data points."""
+    or unclassifiable data points.
+    """
 
     repo_name = "randomcutforest"
     repo_version = 1
@@ -50,16 +51,16 @@ class RandomCutForest(AmazonAlgorithmEstimatorBase):
     def __init__(
         self,
         role,
-        instance_count,
-        instance_type,
+        instance_count=None,
+        instance_type=None,
         num_samples_per_tree=None,
         num_trees=None,
         eval_metrics=None,
         **kwargs
     ):
-        """RandomCutForest is :class:`Estimator` used for anomaly detection.
+        """An `Estimator` class implementing a Random Cut Forest.
 
-        This Estimator may be fit via calls to
+        Typically used for anomaly detection, this Estimator may be fit via calls to
         :meth:`~sagemaker.amazon.amazon_estimator.AmazonAlgorithmEstimatorBase.fit`.
         It requires Amazon :class:`~sagemaker.amazon.record_pb2.Record` protobuf
         serialized data to be stored in S3. There is an utility
