@@ -1,4 +1,4 @@
-# Copyright 2017-2018 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+# Copyright 2017-2020 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License"). You
 # may not use this file except in compliance with the License. A copy of
@@ -10,10 +10,16 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
+"""Placeholder docstring"""
 from __future__ import absolute_import
 
 
 def gt(minimum):
+    """
+    Args:
+        minimum:
+    """
+
     def validate(value):
         return value > minimum
 
@@ -21,6 +27,11 @@ def gt(minimum):
 
 
 def ge(minimum):
+    """
+    Args:
+        minimum:
+    """
+
     def validate(value):
         return value >= minimum
 
@@ -28,6 +39,11 @@ def ge(minimum):
 
 
 def lt(maximum):
+    """
+    Args:
+        maximum:
+    """
+
     def validate(value):
         return value < maximum
 
@@ -35,6 +51,11 @@ def lt(maximum):
 
 
 def le(maximum):
+    """
+    Args:
+        maximum:
+    """
+
     def validate(value):
         return value <= maximum
 
@@ -42,6 +63,11 @@ def le(maximum):
 
 
 def isin(*expected):
+    """
+    Args:
+        *expected:
+    """
+
     def validate(value):
         return value in expected
 
@@ -49,6 +75,11 @@ def isin(*expected):
 
 
 def istype(expected):
+    """
+    Args:
+        expected:
+    """
+
     def validate(value):
         return isinstance(value, expected)
 
