@@ -52,15 +52,14 @@ logger = logging.getLogger(__name__)
 
 
 class _SageMakerContainer(object):
-    """Handle the lifecycle and configuration of a local docker container
-    execution.
+    """Handle the lifecycle and configuration of a local container execution.
 
     This class is responsible for creating the directories and configuration
     files that the docker containers will use for either training or serving.
     """
 
     def __init__(self, instance_type, instance_count, image, sagemaker_session=None):
-        """Initialize a SageMakerContainer instance
+        """Initialize a SageMakerContainer instance.
 
         It uses a :class:`sagemaker.session.Session` for general interaction
         with user configuration such as getting the default sagemaker S3 bucket.
@@ -105,7 +104,7 @@ class _SageMakerContainer(object):
         Args:
             input_data_config (dict): The Input Data Configuration, this contains data such as the
                 channels to be used for training.
-            output_data_config:
+            output_data_config: The configuration of the output data.
             hyperparameters (dict): The HyperParameters for the training job.
             job_name (str): Name of the local training job being run.
 
@@ -180,13 +179,13 @@ class _SageMakerContainer(object):
 
     def serve(self, model_dir, environment):
         """Host a local endpoint using docker-compose.
+
         Args:
             primary_container (dict): dictionary containing the container runtime settings
                 for serving. Expected keys:
                 - 'ModelDataUrl' pointing to a file or s3:// location.
                 - 'Environment' a dictionary of environment variables to be passed to the
                     hosting container.
-
         """
         logger.info("serving")
 
@@ -240,8 +239,8 @@ class _SageMakerContainer(object):
         Args:
             compose_data (dict): Docker-Compose configuration in dictionary
                 format.
-            output_data_config:
-            job_name:
+            output_data_config: The configuration of the output data.
+            job_name: The name of the job.
 
         Returns: Local path to the collected model artifacts.
         """
@@ -332,7 +331,8 @@ class _SageMakerContainer(object):
     def _prepare_training_volumes(
         self, data_dir, input_data_config, output_data_config, hyperparameters
     ):
-        """
+        """Prepares the training volumes based on input and output data configs.
+
         Args:
             data_dir:
             input_data_config:
@@ -379,10 +379,14 @@ class _SageMakerContainer(object):
         return volumes
 
     def _update_local_src_path(self, params, key):
-        """
+        """Updates the local path of source code.
+
         Args:
-            params:
-            key:
+            params: Existing configuration parameters.
+            key: Lookup key for the path of the source code in the configuration parameters.
+
+        Returns:
+            The updated parameters.
         """
         if key in params:
             src_dir = json.loads(params[key])
@@ -394,9 +398,10 @@ class _SageMakerContainer(object):
         return params
 
     def _prepare_serving_volumes(self, model_location):
-        """
+        """Prepares the serving volumes.
+
         Args:
-            model_location:
+            model_location: Location of the models.
         """
         volumes = []
         host = self.hosts[0]
@@ -484,7 +489,8 @@ class _SageMakerContainer(object):
         return content
 
     def _compose(self, detached=False):
-        """
+        """Invokes the docker compose command.
+
         Args:
             detached:
         """
@@ -503,7 +509,8 @@ class _SageMakerContainer(object):
         return command
 
     def _create_docker_host(self, host, environment, optml_subdirs, command, volumes):
-        """
+        """Creates the docker host configuration.
+
         Args:
             host:
             environment:
@@ -559,11 +566,11 @@ class _SageMakerContainer(object):
         return os.path.abspath(working_dir)
 
     def _build_optml_volumes(self, host, subdirs):
-        """Generate a list of :class:`~sagemaker.local_session.Volume` required
-        for the container to start.
+        """Generate a list of :class:`~sagemaker.local_session.Volume`.
 
-        It takes a folder with the necessary files for training and creates a
-        list of opt volumes that the Container needs to start.
+        These are required for the container to start. It takes a folder with
+        the necessary files for training and creates a list of opt volumes
+        that the Container needs to start.
 
         Args:
             host (str): container for which the volumes will be generated.
@@ -583,7 +590,8 @@ class _SageMakerContainer(object):
         return volumes
 
     def _cleanup(self, dirs_to_delete=None):
-        """
+        """Cleans up directories and the like.
+
         Args:
             dirs_to_delete:
         """
@@ -598,10 +606,11 @@ class _SageMakerContainer(object):
 
 
 class _HostingContainer(Thread):
-    """Placeholder docstring"""
+    """Placeholder docstring."""
 
     def __init__(self, command):
-        """
+        """Creates a new threaded hosting container.
+
         Args:
             command:
         """
@@ -631,9 +640,10 @@ class _Volume(object):
     """Represent a Volume that will be mapped to a container."""
 
     def __init__(self, host_dir, container_dir=None, channel=None):
-        """Create a Volume instance
+        """Create a Volume instance.
+
+        The container path can be provided as a container_dir or as a channel name but not both.
 
-        the container path can be provided as a container_dir or as a channel name but not both.
         Args:
             host_dir (str): path to the volume data in the host
             container_dir (str): path inside the container that host_dir will be mapped to
@@ -680,7 +690,8 @@ def _stream_output(process):
 
 
 def _check_output(cmd, *popenargs, **kwargs):
-    """
+    """Makes a call to `subprocess.check_output` for the given command and args.
+
     Args:
         cmd:
         *popenargs:
@@ -705,7 +716,8 @@ def _check_output(cmd, *popenargs, **kwargs):
 
 
 def _create_config_file_directories(root, host):
-    """
+    """Creates the directories for the config files.
+
     Args:
         root:
         host:
@@ -715,7 +727,8 @@ def _create_config_file_directories(root, host):
 
 
 def _delete_tree(path):
-    """
+    """Makes a call to `shutil.rmtree` for the given path.
+
     Args:
         path:
     """
@@ -734,7 +747,10 @@ def _delete_tree(path):
 
 
 def _aws_credentials(session):
-    """
+    """Provides the AWS credentials of the session as a paired list of strings.
+
+    These can be used to set environment variables on command execution.
+
     Args:
         session:
     """
@@ -797,7 +813,8 @@ def _aws_credentials_available_in_metadata_service():
 
 
 def _write_json_file(filename, content):
-    """
+    """Write the contents dict as json to the file.
+
     Args:
         filename:
         content:
@@ -807,8 +824,10 @@ def _write_json_file(filename, content):
 
 
 def _ecr_login_if_needed(boto_session, image):
-    # Only ECR images need login
-    """
+    """Log into ECR, if needed.
+
+    Of note, only ECR images need login.
+
     Args:
         boto_session:
         image:
@@ -843,7 +862,8 @@ def _ecr_login_if_needed(boto_session, image):
 
 
 def _pull_image(image):
-    """
+    """Invokes the docker pull command for the given image.
+
     Args:
         image:
     """
