@@ -72,7 +72,7 @@ class LocalSagemakerClient(object):
         InputDataConfig=None,
         **kwargs
     ):
-        """Create a training job in Local Mode
+        """Create a training job in Local Mode.
 
         Args:
           TrainingJobName(str): local training job name.
@@ -132,7 +132,7 @@ class LocalSagemakerClient(object):
         TransformResources,
         **kwargs
     ):
-        """
+        """Create the transform job.
 
         Args:
           TransformJobName:
@@ -150,7 +150,7 @@ class LocalSagemakerClient(object):
         transform_job.start(TransformInput, TransformOutput, TransformResources, **kwargs)
 
     def describe_transform_job(self, TransformJobName):
-        """
+        """Describe the transform job.
 
         Args:
           TransformJobName:
@@ -171,8 +171,7 @@ class LocalSagemakerClient(object):
     def create_model(
         self, ModelName, PrimaryContainer, *args, **kwargs
     ):  # pylint: disable=unused-argument
-        """Create a Local Model Object
-
+        """Create a Local Model Object.
 
         Args:
           ModelName (str): the Model Name
@@ -185,13 +184,12 @@ class LocalSagemakerClient(object):
         LocalSagemakerClient._models[ModelName] = _LocalModel(ModelName, PrimaryContainer)
 
     def describe_model(self, ModelName):
-        """
+        """Describe the model.
 
         Args:
           ModelName:
 
         Returns:
-
         """
         if ModelName not in LocalSagemakerClient._models:
             error_response = {
@@ -201,7 +199,7 @@ class LocalSagemakerClient(object):
         return LocalSagemakerClient._models[ModelName].describe()
 
     def describe_endpoint_config(self, EndpointConfigName):
-        """
+        """Describe the endpoint configuration.
 
         Args:
           EndpointConfigName:
@@ -220,7 +218,7 @@ class LocalSagemakerClient(object):
         return LocalSagemakerClient._endpoint_configs[EndpointConfigName].describe()
 
     def create_endpoint_config(self, EndpointConfigName, ProductionVariants, Tags=None):
-        """
+        """Create the endpoint configuration.
 
         Args:
           EndpointConfigName:
@@ -235,7 +233,7 @@ class LocalSagemakerClient(object):
         )
 
     def describe_endpoint(self, EndpointName):
-        """
+        """Describe the endpoint.
 
         Args:
           EndpointName:
@@ -251,7 +249,7 @@ class LocalSagemakerClient(object):
         return LocalSagemakerClient._endpoints[EndpointName].describe()
 
     def create_endpoint(self, EndpointName, EndpointConfigName, Tags=None):
-        """
+        """Create the endpoint.
 
         Args:
           EndpointName:
@@ -266,7 +264,7 @@ class LocalSagemakerClient(object):
         endpoint.serve()
 
     def update_endpoint(self, EndpointName, EndpointConfigName):  # pylint: disable=unused-argument
-        """
+        """Update the endpoint.
 
         Args:
           EndpointName:
@@ -278,7 +276,7 @@ class LocalSagemakerClient(object):
         raise NotImplementedError("Update endpoint name is not supported in local session.")
 
     def delete_endpoint(self, EndpointName):
-        """
+        """Delete the endpoint.
 
         Args:
           EndpointName:
@@ -290,7 +288,7 @@ class LocalSagemakerClient(object):
             LocalSagemakerClient._endpoints[EndpointName].stop()
 
     def delete_endpoint_config(self, EndpointConfigName):
-        """
+        """Delete the endpoint configuration.
 
         Args:
           EndpointConfigName:
@@ -302,7 +300,7 @@ class LocalSagemakerClient(object):
             del LocalSagemakerClient._endpoint_configs[EndpointConfigName]
 
     def delete_model(self, ModelName):
-        """
+        """Delete the model.
 
         Args:
           ModelName:
@@ -318,7 +316,7 @@ class LocalSagemakerRuntimeClient(object):
     """A SageMaker Runtime client that calls a local endpoint only."""
 
     def __init__(self, config=None):
-        """Initializes a LocalSageMakerRuntimeClient
+        """Initializes a LocalSageMakerRuntimeClient.
 
         Args:
             config (dict): Optional configuration for this client. In particular only
@@ -345,7 +343,7 @@ class LocalSagemakerRuntimeClient(object):
         TargetModel=None,
         TargetVariant=None,
     ):
-        """
+        """Invoke the endpoint.
 
         Args:
           Body:
@@ -380,7 +378,7 @@ class LocalSagemakerRuntimeClient(object):
 
 
 class LocalSession(Session):
-    """Placeholder docstring"""
+    """A LocalSession class definition."""
 
     def __init__(self, boto_session=None, s3_endpoint_url=None):
         self.s3_endpoint_url = s3_endpoint_url
@@ -390,13 +388,16 @@ class LocalSession(Session):
         if platform.system() == "Windows":
             logger.warning("Windows Support for Local Mode is Experimental")
 
-    def _initialize(self, boto_session, sagemaker_client, sagemaker_runtime_client):
+    def _initialize(
+        self, boto_session, sagemaker_client, sagemaker_runtime_client, **kwargs
+    ):  # pylint: disable=unused-argument
         """Initialize this Local SageMaker Session.
 
         Args:
           boto_session:
           sagemaker_client:
           sagemaker_runtime_client:
+          kwargs:
 
         Returns:
 
@@ -429,7 +430,7 @@ class LocalSession(Session):
             self.config = yaml.load(open(sagemaker_config_file, "r"))
 
     def logs_for_job(self, job_name, wait=False, poll=5, log_type="All"):
-        """
+        """A no-op method meant to override the sagemaker client.
 
         Args:
           job_name:
