@@ -18,7 +18,16 @@ import logging
 import os
 
 import sagemaker
-from sagemaker import fw_utils, image_uris, local, s3, session, utils, git_utils
+from sagemaker import (
+    fw_utils,
+    image_uris,
+    local,
+    s3,
+    session,
+    utils,
+    git_utils,
+)
+from sagemaker.deprecations import removed_kwargs
 from sagemaker.transformer import Transformer
 
 LOGGER = logging.getLogger("sagemaker")
@@ -95,6 +104,144 @@ class Model(object):
         self._enable_network_isolation = enable_network_isolation
         self.model_kms_key = model_kms_key
 
+    def register(
+        self,
+        content_types,
+        response_types,
+        inference_instances,
+        transform_instances,
+        model_package_name=None,
+        model_package_group_name=None,
+        image_uri=None,
+        model_metrics=None,
+        metadata_properties=None,
+        marketplace_cert=False,
+        approval_status=None,
+        description=None,
+    ):
+        """Creates a model package for creating SageMaker models or listing on Marketplace.
+
+        Args:
+            content_types (list): The supported MIME types for the input data (default: None).
+            response_types (list): The supported MIME types for the output data (default: None).
+            inference_instances (list): A list of the instance types that are used to
+                generate inferences in real-time (default: None).
+            transform_instances (list): A list of the instance types on which a transformation
+                job can be run or on which an endpoint can be deployed (default: None).
+            model_package_name (str): Model Package name, exclusive to `model_package_group_name`,
+                using `model_package_name` makes the Model Package un-versioned (default: None).
+            model_package_group_name (str): Model Package Group name, exclusive to
+                `model_package_name`, using `model_package_group_name` makes the Model Package
+                versioned (default: None).
+            image_uri (str): Inference image uri for the container. Model class' self.image will
+                be used if it is None (default: None).
+            model_metrics (ModelMetrics): ModelMetrics object (default: None).
+            metadata_properties (MetadataProperties): MetadataProperties object (default: None).
+            marketplace_cert (bool): A boolean value indicating if the Model Package is certified
+                for AWS Marketplace (default: False).
+            approval_status (str): Model Approval Status, values can be "Approved", "Rejected",
+                or "PendingManualApproval" (default: "PendingManualApproval").
+            description (str): Model Package description (default: None).
+
+        Returns:
+            str: A string of SageMaker Model Package ARN.
+        """
+        if self.model_data is None:
+            raise ValueError("SageMaker Model Package cannot be created without model data.")
+
+        model_pkg_args = self._get_model_package_args(
+            content_types,
+            response_types,
+            inference_instances,
+            transform_instances,
+            model_package_name,
+            model_package_group_name,
+            image_uri,
+            model_metrics,
+            metadata_properties,
+            marketplace_cert,
+            approval_status,
+            description,
+        )
+        model_package = self.sagemaker_session.create_model_package_from_containers(
+            **model_pkg_args
+        )
+        return ModelPackage(
+            role=self.role,
+            model_data=self.model_data,
+            model_package_arn=model_package.get("ModelPackageArn"),
+        )
+
+    def _get_model_package_args(
+        self,
+        content_types,
+        response_types,
+        inference_instances,
+        transform_instances,
+        model_package_name=None,
+        model_package_group_name=None,
+        image_uri=None,
+        model_metrics=None,
+        metadata_properties=None,
+        marketplace_cert=False,
+        approval_status=None,
+        description=None,
+    ):
+        """Get arguments for session.create_model_package method.
+        Args:
+            content_types (list): The supported MIME types for the input data.
+            response_types (list): The supported MIME types for the output data.
+            inference_instances (list): A list of the instance types that are used to
+                generate inferences in real-time.
+            transform_instances (list): A list of the instance types on which a transformation
+                job can be run or on which an endpoint can be deployed.
+            model_package_name (str): Model Package name, exclusive to `model_package_group_name`,
+                using `model_package_name` makes the Model Package un-versioned (default: None).
+            model_package_group_name (str): Model Package Group name, exclusive to
+                `model_package_name`, using `model_package_group_name` makes the Model Package
+                versioned (default: None).
+            image_uri (str): Inference image uri for the container. Model class' self.image will
+                be used if it is None (default: None).
+            model_metrics (ModelMetrics): ModelMetrics object (default: None).
+            metadata_properties (MetadataProperties): MetadataProperties object (default: None).
+            marketplace_cert (bool): A boolean value indicating if the Model Package is certified
+                for AWS Marketplace (default: False).
+            approval_status (str): Model Approval Status, values can be "Approved", "Rejected",
+                or "PendingManualApproval" (default: "PendingManualApproval").
+            description (str): Model Package description (default: None).
+        Returns:
+            dict: A dictionary of method argument names and values.
+        """
+        if image_uri:
+            self.image_uri = image_uri
+        container = {
+            "Image": self.image_uri,
+            "ModelDataUrl": self.model_data,
+        }
+
+        model_package_args = {
+            "containers": [container],
+            "content_types": content_types,
+            "response_types": response_types,
+            "inference_instances": inference_instances,
+            "transform_instances": transform_instances,
+            "marketplace_cert": marketplace_cert,
+        }
+
+        if model_package_name is not None:
+            model_package_args["model_package_name"] = model_package_name
+        if model_package_group_name is not None:
+            model_package_args["model_package_group_name"] = model_package_group_name
+        if model_metrics is not None:
+            model_package_args["model_metrics"] = model_metrics._to_request_dict()
+        if metadata_properties is not None:
+            model_package_args["metadata_properties"] = metadata_properties._to_request_dict()
+        if approval_status is not None:
+            model_package_args["approval_status"] = approval_status
+        if description is not None:
+            model_package_args["description"] = description
+        return model_package_args
+
     def _init_sagemaker_session_if_does_not_exist(self, instance_type):
         """Set ``self.sagemaker_session`` to be a ``LocalSession`` or
         ``Session`` if it is not already. The type of session object is
@@ -274,9 +421,18 @@ class Model(object):
             framework (str): The framework name.
             framework_version (str): The framework version.
         """
-        framework_prefix = "inferentia-" if target_instance_type.startswith("ml_inf") else "neo-"
+        framework_prefix = ""
+        framework_suffix = ""
+
+        if framework == "xgboost":
+            framework_suffix = "-neo"
+        elif target_instance_type.startswith("ml_inf"):
+            framework_prefix = "inferentia-"
+        else:
+            framework_prefix = "neo-"
+
         return image_uris.retrieve(
-            "{}{}".format(framework_prefix, framework),
+            "{}{}{}".format(framework_prefix, framework, framework_suffix),
             region,
             instance_type=target_instance_type,
             version=framework_version,
@@ -415,6 +571,7 @@ class Model(object):
         kms_key=None,
         wait=True,
         data_capture_config=None,
+        **kwargs,
     ):
         """Deploy this ``Model`` to an ``Endpoint`` and optionally return a
         ``Predictor``.
@@ -469,6 +626,7 @@ class Model(object):
                 ``self.predictor_cls`` on the created endpoint name, if ``self.predictor_cls``
                 is not None. Otherwise, return None.
         """
+        removed_kwargs("update_endpoint", kwargs)
         self._init_sagemaker_session_if_does_not_exist(instance_type)
 
         if self.role is None:
@@ -632,7 +790,7 @@ class FrameworkModel(Model):
         sagemaker_session=None,
         dependencies=None,
         git_config=None,
-        **kwargs
+        **kwargs,
     ):
         """Initialize a ``FrameworkModel``.
 
@@ -648,8 +806,8 @@ class FrameworkModel(Model):
                 must point to a file located at the root of ``source_dir``.
                 If 'git_config' is provided, 'entry_point' should be
                 a relative location to the Python source file in the Git repo.
-                Example:
 
+                Example:
                     With the following GitHub repo directory structure:
 
                     >>> |----- README.md
@@ -666,6 +824,7 @@ class FrameworkModel(Model):
                 'source_dir' should be a relative location to a directory in the Git repo.
                 If the directory points to S3, no code will be uploaded and the S3 location
                 will be used instead.
+
                 .. admonition:: Example
 
                     With the following GitHub repo directory structure:
@@ -770,7 +929,8 @@ class FrameworkModel(Model):
                 authentication if they are provided; otherwise, python SDK will
                 try to use either CodeCommit credential helper or local
                 credential storage for authentication.
-            **kwargs: Keyword arguments passed to the ``Model`` initializer.
+            **kwargs: Keyword arguments passed to the superclass
+                :class:`~sagemaker.model.Model`.
 
         .. tip::
 
@@ -785,7 +945,7 @@ class FrameworkModel(Model):
             env=env,
             name=name,
             sagemaker_session=sagemaker_session,
-            **kwargs
+            **kwargs,
         )
         self.entry_point = entry_point
         self.source_dir = source_dir
