@@ -13,9 +13,29 @@
 """Placeholder docstring"""
 from __future__ import print_function, absolute_import
 
-from sagemaker.deserializers import BytesDeserializer
+from sagemaker.deprecations import (
+    deprecated_class,
+    deprecated_deserialize,
+    deprecated_serialize,
+    removed_kwargs,
+    renamed_kwargs,
+    renamed_warning,
+)
+from sagemaker.deserializers import (  # noqa: F401 # pylint: disable=unused-import
+    BytesDeserializer,
+    CSVDeserializer,
+    JSONDeserializer,
+    NumpyDeserializer,
+    StreamDeserializer,
+    StringDeserializer,
+)
 from sagemaker.model_monitor import DataCaptureConfig
-from sagemaker.serializers import IdentitySerializer
+from sagemaker.serializers import (
+    CSVSerializer,
+    IdentitySerializer,
+    JSONSerializer,
+    NumpySerializer,
+)
 from sagemaker.session import production_variant, Session
 from sagemaker.utils import name_from_base
 
@@ -25,6 +45,8 @@ from sagemaker.model_monitor.model_monitoring import (
     DefaultModelMonitor,
 )
 
+from sagemaker.lineage.context import EndpointContext
+
 
 class Predictor(object):
     """Make prediction requests to an Amazon SageMaker endpoint."""
@@ -35,6 +57,7 @@ class Predictor(object):
         sagemaker_session=None,
         serializer=IdentitySerializer(),
         deserializer=BytesDeserializer(),
+        **kwargs,
     ):
         """Initialize a ``Predictor``.
 
@@ -58,12 +81,16 @@ class Predictor(object):
                 deserializer object, used to decode data from an inference
                 endpoint (default: :class:`~sagemaker.deserializers.BytesDeserializer`).
         """
+        removed_kwargs("content_type", kwargs)
+        removed_kwargs("accept", kwargs)
+        endpoint_name = renamed_kwargs("endpoint", "endpoint_name", endpoint_name, kwargs)
         self.endpoint_name = endpoint_name
         self.sagemaker_session = sagemaker_session or Session()
         self.serializer = serializer
         self.deserializer = deserializer
         self._endpoint_config_name = self._get_endpoint_config_name()
         self._model_names = self._get_model_names()
+        self._context = None
 
     def predict(self, data, initial_args=None, target_model=None, target_variant=None):
         """Return the inference from the specified endpoint.
@@ -363,6 +390,42 @@ class Predictor(object):
 
         return monitors
 
+    def endpoint_context(self):
+        """Retrieves the lineage context object representing the endpoint.
+
+        Examples:
+            .. code-block:: python
+
+            predictor = Predictor()
+            ...
+            context = predictor.endpoint_context()
+            models = context.models()
+
+        Returns:
+            ContextEndpoint: The context for the endpoint.
+        """
+        if self._context:
+            return self._context
+
+        # retrieve endpoint by name to get arn
+        response = self.sagemaker_session.sagemaker_client.describe_endpoint(
+            EndpointName=self.endpoint_name
+        )
+        endpoint_arn = response["EndpointArn"]
+
+        # list context by source uri using arn
+        contexts = list(
+            EndpointContext.list(sagemaker_session=self.sagemaker_session, source_uri=endpoint_arn)
+        )
+
+        if len(contexts) != 0:
+            # create endpoint context object
+            self._context = EndpointContext.load(
+                sagemaker_session=self.sagemaker_session, context_name=contexts[0].context_name
+            )
+
+        return self._context
+
     def _get_endpoint_config_name(self):
         """Placeholder docstring"""
         endpoint_desc = self.sagemaker_session.sagemaker_client.describe_endpoint(
@@ -388,3 +451,18 @@ class Predictor(object):
     def accept(self):
         """The content type(s) that are expected from the inference endpoint."""
         return self.deserializer.ACCEPT
+
+    @property
+    def endpoint(self):
+        """Deprecated attribute. Please use endpoint_name."""
+        renamed_warning("The endpoint attribute")
+        return self.endpoint_name
+
+
+csv_serializer = deprecated_serialize(CSVSerializer(), "csv_serializer")
+json_serializer = deprecated_serialize(JSONSerializer(), "json_serializer")
+npy_serializer = deprecated_serialize(NumpySerializer(), "npy_serializer")
+csv_deserializer = deprecated_deserialize(CSVDeserializer(), "csv_deserializer")
+json_deserializer = deprecated_deserialize(JSONDeserializer(), "json_deserializer")
+numpy_deserializer = deprecated_deserialize(NumpyDeserializer(), "numpy_deserializer")
+RealTimePredictor = deprecated_class(Predictor, "RealTimePredictor")
