@@ -21,12 +21,14 @@ import os
 import pathlib
 
 from six.moves.urllib.parse import urlparse
+from six.moves.urllib.request import url2pathname
 
 from sagemaker import s3
 from sagemaker.job import _Job
 from sagemaker.utils import base_name_from_image, name_from_base
 from sagemaker.session import Session
 from sagemaker.network import NetworkConfig  # noqa: F401 # pylint: disable=unused-import
+from sagemaker.workflow.properties import Properties
 
 
 class Processor(object):
@@ -119,6 +121,7 @@ class Processor(object):
         logs=True,
         job_name=None,
         experiment_config=None,
+        kms_key=None,
     ):
         """Runs a processing job.
 
@@ -139,6 +142,8 @@ class Processor(object):
             experiment_config (dict[str, str]): Experiment management configuration.
                 Dictionary contains three optional keys:
                 'ExperimentName', 'TrialName', and 'TrialComponentDisplayName'.
+            kms_key (str): The ARN of the KMS key that is used to encrypt the
+                user code file (default: None).
 
         Raises:
             ValueError: if ``logs`` is True but ``wait`` is False.
@@ -153,6 +158,7 @@ class Processor(object):
             job_name=job_name,
             arguments=arguments,
             inputs=inputs,
+            kms_key=kms_key,
             outputs=outputs,
         )
 
@@ -166,7 +172,19 @@ class Processor(object):
         if wait:
             self.latest_job.wait(logs=logs)
 
-    def _normalize_args(self, job_name=None, arguments=None, inputs=None, outputs=None, code=None):
+    def _extend_processing_args(self, inputs, outputs, **kwargs):  # pylint: disable=W0613
+        """Extend inputs and outputs based on extra parameters"""
+        return inputs, outputs
+
+    def _normalize_args(
+        self,
+        job_name=None,
+        arguments=None,
+        inputs=None,
+        outputs=None,
+        code=None,
+        kms_key=None,
+    ):
         """Normalizes the arguments so that they can be passed to the job run
 
         Args:
@@ -178,6 +196,8 @@ class Processor(object):
             inputs (list[:class:`~sagemaker.processing.ProcessingInput`]): Input files for
                 the processing job. These must be provided as
                 :class:`~sagemaker.processing.ProcessingInput` objects (default: None).
+            kms_key (str): The ARN of the KMS key that is used to encrypt the
+                user code file (default: None).
             outputs (list[:class:`~sagemaker.processing.ProcessingOutput`]): Outputs for
                 the processing job. These can be specified as either path strings or
                 :class:`~sagemaker.processing.ProcessingOutput` objects (default: None).
@@ -187,7 +207,7 @@ class Processor(object):
         self._current_job_name = self._generate_current_job_name(job_name=job_name)
 
         inputs_with_code = self._include_code_in_inputs(inputs, code)
-        normalized_inputs = self._normalize_inputs(inputs_with_code)
+        normalized_inputs = self._normalize_inputs(inputs_with_code, kms_key)
         normalized_outputs = self._normalize_outputs(outputs)
         self.arguments = arguments
 
@@ -229,13 +249,15 @@ class Processor(object):
 
         return name_from_base(base_name)
 
-    def _normalize_inputs(self, inputs=None):
+    def _normalize_inputs(self, inputs=None, kms_key=None):
         """Ensures that all the ``ProcessingInput`` objects have names and S3 URIs.
 
         Args:
             inputs (list[sagemaker.processing.ProcessingInput]): A list of ``ProcessingInput``
                 objects to be normalized (default: None). If not specified,
                 an empty list is returned.
+            kms_key (str): The ARN of the KMS key that is used to encrypt the
+                user code file (default: None).
 
         Returns:
             list[sagemaker.processing.ProcessingInput]: The list of normalized
@@ -254,6 +276,11 @@ class Processor(object):
                 # Generate a name for the ProcessingInput if it doesn't have one.
                 if file_input.input_name is None:
                     file_input.input_name = "input-{}".format(count)
+
+                if isinstance(file_input.source, Properties):
+                    normalized_inputs.append(file_input)
+                    continue
+
                 # If the source is a local path, upload it to S3
                 # and save the S3 uri in the ProcessingInput source.
                 parse_result = urlparse(file_input.source)
@@ -269,6 +296,7 @@ class Processor(object):
                         local_path=file_input.source,
                         desired_s3_uri=desired_s3_uri,
                         sagemaker_session=self.sagemaker_session,
+                        kms_key=kms_key,
                     )
                     file_input.source = s3_uri
                 normalized_inputs.append(file_input)
@@ -408,6 +436,7 @@ class ScriptProcessor(Processor):
         logs=True,
         job_name=None,
         experiment_config=None,
+        kms_key=None,
     ):
         """Runs a processing job.
 
@@ -430,6 +459,8 @@ class ScriptProcessor(Processor):
             experiment_config (dict[str, str]): Experiment management configuration.
                 Dictionary contains three optional keys:
                 'ExperimentName', 'TrialName', and 'TrialComponentDisplayName'.
+            kms_key (str): The ARN of the KMS key that is used to encrypt the
+                user code file (default: None).
         """
         normalized_inputs, normalized_outputs = self._normalize_args(
             job_name=job_name,
@@ -437,6 +468,7 @@ class ScriptProcessor(Processor):
             inputs=inputs,
             outputs=outputs,
             code=code,
+            kms_key=kms_key,
         )
 
         self.latest_job = ProcessingJob.start_new(
@@ -510,21 +542,22 @@ class ScriptProcessor(Processor):
             user_code_s3_uri = code
         elif code_url.scheme == "" or code_url.scheme == "file":
             # Validate that the file exists locally and is not a directory.
-            if not os.path.exists(code):
+            code_path = url2pathname(code_url.path)
+            if not os.path.exists(code_path):
                 raise ValueError(
                     """code {} wasn't found. Please make sure that the file exists.
                     """.format(
                         code
                     )
                 )
-            if not os.path.isfile(code):
+            if not os.path.isfile(code_path):
                 raise ValueError(
                     """code {} must be a file, not a directory. Please pass a path to a file.
                     """.format(
                         code
                     )
                 )
-            user_code_s3_uri = self._upload_code(code)
+            user_code_s3_uri = self._upload_code(code_path)
         else:
             raise ValueError(
                 "code {} url scheme {} is not recognized. Please pass a file path or S3 url".format(
@@ -927,8 +960,10 @@ class ProcessingJob(_Job):
 
 
 class ProcessingInput(object):
-    """Accepts parameters that specify an Amazon S3 input for a processing job and
-    provides a method to turn those parameters into a dictionary."""
+    """Accepts parameters that specify an Amazon S3 input for a processing job.
+
+    Also provides a method to turn those parameters into a dictionary.
+    """
 
     def __init__(
         self,
@@ -990,8 +1025,10 @@ class ProcessingInput(object):
 
 
 class ProcessingOutput(object):
-    """Accepts parameters that specify an Amazon S3 output for a processing job and provides
-    a method to turn those parameters into a dictionary."""
+    """Accepts parameters that specify an Amazon S3 output for a processing job.
+
+    It also provides a method to turn those parameters into a dictionary.
+    """
 
     def __init__(self, source, destination=None, output_name=None, s3_upload_mode="EndOfJob"):
         """Initializes a ``ProcessingOutput`` instance. ``ProcessingOutput`` accepts parameters that
