@@ -18,6 +18,7 @@ import logging
 import sagemaker
 from sagemaker import image_uris, s3
 from sagemaker.deserializers import JSONDeserializer
+from sagemaker.deprecations import removed_kwargs
 from sagemaker.predictor import Predictor
 from sagemaker.serializers import JSONSerializer
 
@@ -35,9 +36,11 @@ class TensorFlowPredictor(Predictor):
         deserializer=JSONDeserializer(),
         model_name=None,
         model_version=None,
+        **kwargs,
     ):
-        """Initialize a ``TensorFlowPredictor``. See :class:`~sagemaker.predictor.Predictor`
-        for more info about parameters.
+        """Initialize a ``TensorFlowPredictor``.
+
+        See :class:`~sagemaker.predictor.Predictor` for more info about parameters.
 
         Args:
             endpoint_name (str): The name of the endpoint to perform inference
@@ -57,6 +60,8 @@ class TensorFlowPredictor(Predictor):
                 that should handle the request. If not specified, the latest
                 version of the model will be used.
         """
+        removed_kwargs("content_type", kwargs)
+        removed_kwargs("accept", kwargs)
         super(TensorFlowPredictor, self).__init__(
             endpoint_name,
             sagemaker_session,
@@ -140,7 +145,7 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         framework_version=None,
         container_log_level=None,
         predictor_cls=TensorFlowPredictor,
-        **kwargs
+        **kwargs,
     ):
         """Initialize a Model.
 
@@ -170,7 +175,9 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
                 to call to create a predictor with an endpoint name and
                 SageMaker ``Session``. If specified, ``deploy()`` returns the
                 result of invoking this function on the created endpoint name.
-            **kwargs: Keyword arguments passed to the ``Model`` initializer.
+            **kwargs: Keyword arguments passed to the superclass
+                :class:`~sagemaker.model.FrameworkModel` and, subsequently, its
+                superclass :class:`~sagemaker.model.Model`.
 
         .. tip::
 
@@ -191,10 +198,77 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             image_uri=image_uri,
             predictor_cls=predictor_cls,
             entry_point=entry_point,
-            **kwargs
+            **kwargs,
         )
         self._container_log_level = container_log_level
 
+    def register(
+        self,
+        content_types,
+        response_types,
+        inference_instances,
+        transform_instances,
+        model_package_name=None,
+        model_package_group_name=None,
+        image_uri=None,
+        model_metrics=None,
+        metadata_properties=None,
+        marketplace_cert=False,
+        approval_status=None,
+        description=None,
+    ):
+        """Creates a model package for creating SageMaker models or listing on Marketplace.
+
+        Args:
+            content_types (list): The supported MIME types for the input data.
+            response_types (list): The supported MIME types for the output data.
+            inference_instances (list): A list of the instance types that are used to
+                generate inferences in real-time.
+            transform_instances (list): A list of the instance types on which a transformation
+                job can be run or on which an endpoint can be deployed.
+            model_package_name (str): Model Package name, exclusive to `model_package_group_name`,
+                using `model_package_name` makes the Model Package un-versioned (default: None).
+            model_package_group_name (str): Model Package Group name, exclusive to
+                `model_package_name`, using `model_package_group_name` makes the Model Package
+                versioned (default: None).
+            image_uri (str): Inference image uri for the container. Model class' self.image will
+                be used if it is None (default: None).
+            model_metrics (ModelMetrics): ModelMetrics object (default: None).
+            metadata_properties (MetadataProperties): MetadataProperties object (default: None).
+            marketplace_cert (bool): A boolean value indicating if the Model Package is certified
+                for AWS Marketplace (default: False).
+            approval_status (str): Model Approval Status, values can be "Approved", "Rejected",
+                or "PendingManualApproval" (default: "PendingManualApproval").
+            description (str): Model Package description (default: None).
+
+        Returns:
+            str: A string of SageMaker Model Package ARN.
+        """
+        instance_type = inference_instances[0]
+        self._init_sagemaker_session_if_does_not_exist(instance_type)
+
+        if image_uri:
+            self.image_uri = image_uri
+        if not self.image_uri:
+            self.image_uri = self.serving_image_uri(
+                region_name=self.sagemaker_session.boto_session.region_name,
+                instance_type=instance_type,
+            )
+        return super(TensorFlowModel, self).register(
+            content_types,
+            response_types,
+            inference_instances,
+            transform_instances,
+            model_package_name,
+            model_package_group_name,
+            image_uri,
+            model_metrics,
+            metadata_properties,
+            marketplace_cert,
+            approval_status,
+            description,
+        )
+
     def deploy(
         self,
         initial_instance_count,
@@ -207,7 +281,9 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         kms_key=None,
         wait=True,
         data_capture_config=None,
+        update_endpoint=None,
     ):
+        """Deploy a Tensorflow ``Model`` to a SageMaker ``Endpoint``."""
 
         if accelerator_type and not self._eia_supported():
             msg = "The TensorFlow version %s doesn't support EIA." % self.framework_version
@@ -224,6 +300,7 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
             kms_key=kms_key,
             wait=wait,
             data_capture_config=data_capture_config,
+            update_endpoint=update_endpoint,
         )
 
     def _eia_supported(self):
@@ -231,10 +308,14 @@ class TensorFlowModel(sagemaker.model.FrameworkModel):
         return [int(s) for s in self.framework_version.split(".")][:2] <= self.LATEST_EIA_VERSION
 
     def prepare_container_def(self, instance_type=None, accelerator_type=None):
-        """
+        """Prepare the container definition.
+
         Args:
-            instance_type:
-            accelerator_type:
+            instance_type: Instance type of the container.
+            accelerator_type: Accelerator type, if applicable.
+
+        Returns:
+            A container definition for deploying a ``Model`` to an ``Endpoint``.
         """
         if self.image_uri is None and instance_type is None:
             raise ValueError(
